@@ -45,7 +45,7 @@ instance Pretty Val where
             JOne  -> " ^ "
             JNone -> " ! "
     pretty (VPair x y) = "(" ++ pretty x ++ " => " ++ pretty y ++ ")"
-    pretty (VBool x) = if x then "#t" else "#f"
+    pretty (VBool x) = if x then "bool::true" else "bool::false"
     pretty (VNum x) = if x == 1/0 then "Inf" else show x
     pretty (VInt x) = show x
     pretty (VStr x) = show x -- XXX escaping
@@ -65,6 +65,8 @@ instance Pretty Val where
     pretty (VError x y) = "*** Error: " ++ x ++ "\n    in " ++ show y
     pretty (VArray (MkArray x)) = pretty (VList x)
     pretty (VHash (MkHash x)) = show x
+    pretty (VHandle x) = show x
+    pretty (MVal x) = "<mval>" -- pretty $ castV x
     pretty VUndef = "undef"
 
 joinList x y = concat $ intersperse x y
